package com.huimv.eartag.manager.controller;



import com.github.pagehelper.PageInfo;
import com.huimv.eartag.manager.entity.Result;
import com.huimv.eartag.manager.entity.StatusCode;
import com.huimv.eartag.manager.pojo.FarmInfo;
import com.huimv.eartag.manager.service.FarmInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/****
 * @Author:shenkunlin
 * @Description:
 * @Date 2019/6/14 0:18
 *****/

@RestController
@RequestMapping("/farmInfo")
@CrossOrigin
public class FarmInfoController {

    @Autowired
    private FarmInfoService farmInfoService;

    /***
     * FarmInfo分页条件搜索实现
     * @param farmInfo
     * @param page
     * @param size
     * @return
     */
    @PostMapping(value = "/search/{page}/{size}" )
    public Result<PageInfo> findPage(@RequestBody(required = false) FarmInfo farmInfo, @PathVariable  int page, @PathVariable  int size){
        //调用FarmInfoService实现分页条件查询FarmInfo
        PageInfo<FarmInfo> pageInfo = farmInfoService.findPage(farmInfo, page, size);
        return new Result(true, StatusCode.OK,"查询成功",pageInfo);
    }

    /***
     * FarmInfo分页搜索实现
     * @param page:当前页
     * @param size:每页显示多少条
     * @return
     */
    @GetMapping(value = "/search/{page}/{size}" )
    public Result<PageInfo> findPage(@PathVariable  int page, @PathVariable  int size){
        //调用FarmInfoService实现分页查询FarmInfo
        PageInfo<FarmInfo> pageInfo = farmInfoService.findPage(page, size);
        return new Result<PageInfo>(true,StatusCode.OK,"查询成功",pageInfo);
    }




    /***
     * 多条件搜索品牌数据
     * @param farmInfo
     * @return
     */
    @PostMapping(value = "/search" )
    public Result<List<FarmInfo>> findList(@RequestBody(required = false)  FarmInfo farmInfo){
        //调用FarmInfoService实现条件查询FarmInfo
        List<FarmInfo> list = farmInfoService.findList(farmInfo);
        return new Result<List<FarmInfo>>(true,StatusCode.OK,"查询成功",list);
    }

    /***
     * 根据ID删除品牌数据
     * @param id
     * @return
     */
    @DeleteMapping(value = "/{id}" )
    public Result delete(@PathVariable Integer id){
        //调用FarmInfoService实现根据主键删除
        farmInfoService.delete(id);
        return new Result(true,StatusCode.OK,"删除成功");
    }

    /***
     * 修改FarmInfo数据
     * @param farmInfo
     * @param id
     * @return
     */
    @PutMapping(value="/{id}")
    public Result update(@RequestBody  FarmInfo farmInfo,@PathVariable Integer id){
        //设置主键值
        farmInfo.setId(id);
        //调用FarmInfoService实现修改FarmInfo
        farmInfoService.update(farmInfo);
        return new Result(true,StatusCode.OK,"修改成功");
    }



    /***
     * 新增FarmInfo数据
     * @param farmInfo
     * @return
     */
    @PostMapping
    public Result add(@RequestBody   FarmInfo farmInfo){
        //调用FarmInfoService实现添加FarmInfo
        farmInfoService.add(farmInfo);
        return new Result(true, StatusCode.OK,"添加成功");
    }


    /***
     * 根据ID查询FarmInfo数据
     * @param id
     * @return
     */
    @GetMapping("/{id}")
    public Result<FarmInfo> findById(@PathVariable Integer id){
        //调用FarmInfoService实现根据主键查询FarmInfo
        FarmInfo farmInfo = farmInfoService.findById(id);
        return new Result<FarmInfo>(true,StatusCode.OK,"查询成功",farmInfo);
    }

    /***
     * 查询FarmInfo全部数据
     * @return
     */
    @GetMapping
    public Result<List<FarmInfo>> findAll(){
        //调用FarmInfoService实现查询所有FarmInfo
        List<FarmInfo> list = farmInfoService.findAll();
        return new Result<List<FarmInfo>>(true, StatusCode.OK,"查询成功",list) ;
    }
}
