package com.huimv.eartag.manager.service.impl;




import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.huimv.eartag.manager.dao.FarmInfoMapper;
import com.huimv.eartag.manager.pojo.FarmInfo;
import com.huimv.eartag.manager.service.FarmInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;
import tk.mybatis.mapper.entity.Example;

import java.util.List;

/****
 * @Author:shenkunlin
 * @Description:FarmInfo业务层接口实现类
 * @Date 2019/6/14 0:16
 *****/
@Service
public class FarmInfoServiceImpl implements FarmInfoService {

    @Autowired
    private FarmInfoMapper farmInfoMapper;


    /**
     * FarmInfo条件+分页查询
     * @param farmInfo 查询条件
     * @param page 页码
     * @param size 页大小
     * @return 分页结果
     */
    @Override
    public PageInfo<FarmInfo> findPage(FarmInfo farmInfo, int page, int size){
        //分页
        PageHelper.startPage(page,size);
        //搜索条件构建
        Example example = createExample(farmInfo);
        //执行搜索
        return new PageInfo<FarmInfo>(farmInfoMapper.selectByExample(example));
    }

    /**
     * FarmInfo分页查询
     * @param page
     * @param size
     * @return
     */
    @Override
    public PageInfo<FarmInfo> findPage(int page, int size){
        //静态分页
        PageHelper.startPage(page,size);
        //分页查询
        return new PageInfo<FarmInfo>(farmInfoMapper.selectAll());
    }

    /**
     * FarmInfo条件查询
     * @param farmInfo
     * @return
     */
    @Override
    public List<FarmInfo> findList(FarmInfo farmInfo){
        //构建查询条件
        Example example = createExample(farmInfo);
        //根据构建的条件查询数据
        return farmInfoMapper.selectByExample(example);
    }


    /**
     * FarmInfo构建查询对象
     * @param farmInfo
     * @return
     */
    public Example createExample(FarmInfo farmInfo){
        Example example=new Example(FarmInfo.class);
        Example.Criteria criteria = example.createCriteria();
        if(farmInfo!=null){
            // 
            if(!StringUtils.isEmpty(farmInfo.getId())){
                    criteria.andEqualTo("id",farmInfo.getId());
            }
            // 牧场名称
            if(!StringUtils.isEmpty(farmInfo.getName())){
                    criteria.andLike("name","%"+farmInfo.getName()+"%");
            }
            // 牧场地址
            if(!StringUtils.isEmpty(farmInfo.getAddress())){
                    criteria.andEqualTo("address",farmInfo.getAddress());
            }
            // 电话
            if(!StringUtils.isEmpty(farmInfo.getTel())){
                    criteria.andEqualTo("tel",farmInfo.getTel());
            }
            // 备注
            if(!StringUtils.isEmpty(farmInfo.getRemark())){
                    criteria.andEqualTo("remark",farmInfo.getRemark());
            }
        }
        return example;
    }

    /**
     * 删除
     * @param id
     */
    @Override
    public void delete(Integer id){
        farmInfoMapper.deleteByPrimaryKey(id);
    }

    /**
     * 修改FarmInfo
     * @param farmInfo
     */
    @Override
    public void update(FarmInfo farmInfo){
        farmInfoMapper.updateByPrimaryKey(farmInfo);
    }

    /**
     * 增加FarmInfo
     * @param farmInfo
     */
    @Override
    public void add(FarmInfo farmInfo){
        farmInfoMapper.insert(farmInfo);
    }

    /**
     * 根据ID查询FarmInfo
     * @param id
     * @return
     */
    @Override
    public FarmInfo findById(Integer id){
        return  farmInfoMapper.selectByPrimaryKey(id);
    }

    /**
     * 查询FarmInfo全部数据
     * @return
     */
    @Override
    public List<FarmInfo> findAll() {
        return farmInfoMapper.selectAll();
    }
}
