package com.huimv.eartag.monitor.controller;



import com.github.pagehelper.PageInfo;
import com.huimv.eartag.monitor.entity.Result;
import com.huimv.eartag.monitor.entity.StatusCode;
import com.huimv.eartag.monitor.pojo.PigHome;
import com.huimv.eartag.monitor.service.PigHomeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/****
 * @Author:shenkunlin
 * @Description:
 * @Date 2019/6/14 0:18
 *****/

@RestController
@RequestMapping("/pigHome")
@CrossOrigin
public class PigHomeController {

    @Autowired
    private PigHomeService pigHomeService;

    /***
     * PigHome分页条件搜索实现
     * @param pigHome
     * @param page
     * @param size
     * @return
     */
    @PostMapping(value = "/search/{page}/{size}" )
    public Result<PageInfo> findPage(@RequestBody(required = false) PigHome pigHome, @PathVariable  int page, @PathVariable  int size){
        //调用PigHomeService实现分页条件查询PigHome
        PageInfo<PigHome> pageInfo = pigHomeService.findPage(pigHome, page, size);
        return new Result(true, StatusCode.OK,"查询成功",pageInfo);
    }

    /***
     * PigHome分页搜索实现
     * @param page:当前页
     * @param size:每页显示多少条
     * @return
     */
    @GetMapping(value = "/search/{page}/{size}" )
    public Result<PageInfo> findPage(@PathVariable  int page, @PathVariable  int size){
        //调用PigHomeService实现分页查询PigHome
        PageInfo<PigHome> pageInfo = pigHomeService.findPage(page, size);
        return new Result<PageInfo>(true,StatusCode.OK,"查询成功",pageInfo);
    }

    /***
     * 多条件搜索品牌数据
     * @param pigHome
     * @return
     */
    @PostMapping(value = "/search" )
    public Result<List<PigHome>> findList(@RequestBody(required = false)  PigHome pigHome){
        //调用PigHomeService实现条件查询PigHome
        List<PigHome> list = pigHomeService.findList(pigHome);
        return new Result<List<PigHome>>(true,StatusCode.OK,"查询成功",list);
    }

    /***
     * 根据ID删除品牌数据
     * @param id
     * @return
     */
    @DeleteMapping(value = "/{id}" )
    public Result delete(@PathVariable Integer id){
        //调用PigHomeService实现根据主键删除
        pigHomeService.delete(id);
        return new Result(true,StatusCode.OK,"删除成功");
    }

    /***
     * 修改PigHome数据
     * @param pigHome
     * @param id
     * @return
     */
    @PutMapping(value="/{id}")
    public Result update(@RequestBody  PigHome pigHome,@PathVariable Integer id){
        //设置主键值
        pigHome.setId(id);
        //调用PigHomeService实现修改PigHome
        pigHomeService.update(pigHome);
        return new Result(true, StatusCode.OK,"修改成功");
    }

    /***
     * 新增PigHome数据
     * @param pigHome
     * @return
     */
    @PostMapping
    public Result add(@RequestBody   PigHome pigHome){
        //调用PigHomeService实现添加PigHome
        pigHomeService.add(pigHome);
        return new Result(true,StatusCode.OK,"添加成功");
    }

    /***
     * 根据ID查询PigHome数据
     * @param id
     * @return
     */
    @GetMapping("/{id}")
    public Result<PigHome> findById(@PathVariable Integer id){
        //调用PigHomeService实现根据主键查询PigHome
        PigHome pigHome = pigHomeService.findById(id);
        return new Result<PigHome>(true,StatusCode.OK,"查询成功",pigHome);
    }

    /***
     * 查询PigHome全部数据
     * @return
     */
    @GetMapping
    public Result<List<PigHome>> findAll(){
        //调用PigHomeService实现查询所有PigHome
        List<PigHome> list = pigHomeService.findAll();
        return new Result<List<PigHome>>(true, StatusCode.OK,"查询成功",list) ;
    }
}
